==> webStore_2.8.2_estable.zip: comunes/procesos_seccion/facturas.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 23/Octubre/2015
	// Versión 1.0 Recogemos los datos que utilizaremos en el orden y filtrado de facturas
	//---------------------------------------------------------------------------------------------------------
	
	
	
	include('comunes/globals.php');
	
	//El funcionamiento es sencillo, miramos si alguna de las variables está activa en las cookies. En caso afirmativo las metemos en la sesión, limpiamos esas cookies
	//y recargamos la página
	
	//---------------------------------------------------------------------------------------------------------
	//Filtrados
	//---------------------------------------------------------------------------------------------------------
	$fecha_inicio_facturas = Sesion::getCookieValue('fecha_inicio');
	$fecha_fin_facturas = Sesion::getCookieValue('fecha_fin');

    $recargar_web = $recargar_web | false;
	//Si nos han pasado fecha de inicio la metemos en la sesión
	if ($fecha_inicio_facturas != NULL){
		Sesion::set('fecha_inicio_facturas', $fecha_inicio_facturas);
		borrarCookie('fecha_inicio');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}
	
	//Si nos han pasado fecha de fin, la metemos en la sesión
	if ($fecha_fin_facturas != NULL){
		Sesion::set('fecha_fin_facturas', $fecha_fin_facturas);
		borrarCookie('fecha_fin');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}
	
	//---------------------------------------------------------------------------------------------------------
	//Orden
	//---------------------------------------------------------------------------------------------------------
	$orden_facturas = Sesion::getCookieValue('orden');
	$tipo_orden_facturas = Sesion::getCookieValue('tipo_orden');


	//Controlamos si nos han pasado un orden
	if ($orden_facturas != NULL){
		Sesion::set('orden_facturas', $orden_facturas);
		borrarCookie('orden');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}
	//Hay que controlar el tipo de orden (ascendente o descendente)
	if ($tipo_orden_facturas != NULL){
		Sesion::set('tipo_orden_facturas', $tipo_orden_facturas);
		borrarCookie('tipo_orden');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}
	
	//---------------------------------------------------------------------------------------------------------
	//Limpiamos las cookies
	//---------------------------------------------------------------------------------------------------------
	$limpiar_filtrado= Sesion::getCookieValue('limpiar_filtrado');
	if ($limpiar_filtrado != NULL){
		Sesion::set('fecha_inicio_facturas', '');
		Sesion::set('fecha_fin_facturas', '');
		borrarCookie('limpiar_filtrado');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}
?>

==> webStore_2.8.9.003_estable.zip: comunes/procesos_seccion/facturas.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 23/Octubre/2015
	// Versión 1.0 Recogemos los datos que utilizaremos en el orden y filtrado de facturas
	//---------------------------------------------------------------------------------------------------------
	
	
	
	include('comunes/globals.php');
	
	//El funcionamiento es sencillo, miramos si alguna de las variables está activa en las cookies. En caso afirmativo las metemos en la sesión, limpiamos esas cookies
	//y recargamos la página
	
	//---------------------------------------------------------------------------------------------------------
	//Filtrados
	//---------------------------------------------------------------------------------------------------------
	$fecha_inicio_facturas = Sesion::getCookieValue('fecha_inicio');
	$fecha_fin_facturas = Sesion::getCookieValue('fecha_fin');

    $recargar_web = $recargar_web | false;
	//Si nos han pasado fecha de inicio la metemos en la sesión
	if ($fecha_inicio_facturas != NULL){
		Sesion::set('fecha_inicio_facturas', $fecha_inicio_facturas);
		borrarCookie('fecha_inicio');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}
	
	//Si nos han pasado fecha de fin, la metemos en la sesión
	if ($fecha_fin_facturas != NULL){
		Sesion::set('fecha_fin_facturas', $fecha_fin_facturas);
		borrarCookie('fecha_fin');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}
	
	//---------------------------------------------------------------------------------------------------------
	//Orden
	//---------------------------------------------------------------------------------------------------------
	$orden_facturas = Sesion::getCookieValue('orden');
	$tipo_orden_facturas = Sesion::getCookieValue('tipo_orden');


	//Controlamos si nos han pasado un orden
	if ($orden_facturas != NULL){
		Sesion::set('orden_facturas', $orden_facturas);
		borrarCookie('orden');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}
	//Hay que controlar el tipo de orden (ascendente o descendente)
	if ($tipo_orden_facturas != NULL){
		Sesion::set('tipo_orden_facturas', $tipo_orden_facturas);
		borrarCookie('tipo_orden');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}
	
	//---------------------------------------------------------------------------------------------------------
	//Limpiamos las cookies
	//---------------------------------------------------------------------------------------------------------
	$limpiar_filtrado= Sesion::getCookieValue('limpiar_filtrado');
	if ($limpiar_filtrado != NULL){
		Sesion::set('fecha_inicio_facturas', '');
		Sesion::set('fecha_fin_facturas', '');
		borrarCookie('limpiar_filtrado');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}
?>
